Acknowledging this Package
==========================

If you use this package in your scientific work, we would appreciate citing it in your publications.
Proper citations and acknowledgement is key to a healthy scientific community and enables scientific reproducibility.

Citing in Publications
----------------------

Please add the following line within your methods, conclusion or acknowledgements sections:

   *This research used version X.Y.Z (software citation) of the SWxSOC Schema open source
   software package (paper citation).*

The software citation should be the specific `Zenodo DOI`_ for the version used in your work.
A paper citation does not yet exist.
